crop_image library
Functions
-
cropImageBytes(
Uint8List source, Rect srcRect, {ImageByteFormat format = ui.ImageByteFormat.png}) → Future< Uint8List> - Crop a region of an image, returning the cropped bytes.
-
displayRectToSourceRect(
{required Rect cropRect, required Rect imageDisplayRect, required Size sourceSize}) → Rect - Convert a crop rect from display coordinates to source-image pixel coordinates.