ScaleExt extension
Methods
-
imageRectOnDragCropRect(
{required Rect container, required Rect imageRect, required Rect cropRect, double overdragMax = 3.0}) → Rect -
Available on ScaleUpdateDetails, provided by the ScaleExt extension
When the crop rect is pinned against the image edge, drags the image along the finger by an amount weighted by the focal's distance to each crop edge.overdragMaxcaps per-frame catch-up. -
rect(
{required Rect startRect, required Rect currentRect}) → Rect -
Available on ScaleUpdateDetails, provided by the ScaleExt extension