AnchorContext class
Inputs supplied to Overrides.anchor when computing the rect's center
during a drag with DragGesture.scaleResponse.
Constructors
Properties
- currentFocalPoint → Offset
-
final
- currentRect → Rect
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
newWidth / startRect.width— the scale ratio that should drive anchor adjustment.final - startFocalPoint → Offset
-
final
- startRect → Rect
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited