Bounds class sealed
Shared base for bound configurations.
Carries the cross-cutting per-bound fields (friction, decay, builder). Subclasses add bound-type-specific fields (e.g., ShrinkBounds.minScale).
- Implementers
Properties
- builder → StageBuilder?
-
final
- decay → DecayConfig?
-
final
- friction → FrictionConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited