onTap property

OnStageTap? onTap
final

Cascade fallback for displayed-state single-tap. Resolved as: displayConfig > stage > package default (no-op). Use this to react to taps on the displayed view — e.g. toggle a chrome overlay when the tap is StageTapEvent.insideRect, dismiss otherwise.

Implementation

final OnStageTap? onTap;