DragBounds class

Inheritance

Constructors

DragBounds({FrictionConfig? friction, DecayConfig? decay, StageBuilder? builder, ScaleResponse? scaleResponse})
const

Properties

builder StageBuilder?
finalinherited
decay DecayConfig?
finalinherited
friction FrictionConfig?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleResponse ScaleResponse?
Per-bound override of DragGesture.scaleResponse. Couples rect width to drag-progress through this bound. Native physics (rect.width changes), not a visual transform. When configured, the drag uses focal-point- preserving anchor math instead of plain translation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited