DragPromote enum
What Stage does in displayed state when a 2nd pointer is added while a DragGesture is the active gesture. Cascade: per-gesture > per-displayConfig
per-stage > scale default.
Values
- lock → const DragPromote
-
Keep the drag; adding a 2nd pointer does not re-resolve to a scale gesture.
- scale → const DragPromote
-
Default. On 2nd-pointer add, scale arena re-resolves against Stage.scale ∪ DisplayConfig.scale.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DragPromote> - A constant List of the values in this enum, in order of their declaration.