ExpandBounds class
Constructors
- ExpandBounds({FrictionConfig? friction, DecayConfig? decay, StageBuilder? builder, double? maxScale})
-
const
Properties
- builder → StageBuilder?
-
finalinherited
- decay → DecayConfig?
-
finalinherited
- friction → FrictionConfig?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxScale → double?
-
Scale above which the rect is "past display." Null = no maximum.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited