Friction class

Resistance to motion during an active gesture, as a function of progress through a bound state. Range 0, 1: 0 = no resistance, 1 = block.

Constructors

Friction(double value, {double? end, Curve curve = Curves.linear})
const

Properties

curve Curve
final
end double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start double
final

Methods

evaluate(double progress) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited