GestureBound enum

Inheritance
Available extensions

Values

left → const GestureBound
up → const GestureBound
down → const GestureBound
zoomIn → const GestureBound
zoomOut → const GestureBound

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isDirectional bool
no setter
isHorizontal bool
no setter
isScale bool
no setter
isVertical bool
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

all Set<GestureBound>
final

Constants

directional → const Set<GestureBound>
horizontal → const Set<GestureBound>
scale → const Set<GestureBound>
values → const List<GestureBound>
A constant List of the values in this enum, in order of their declaration.
vertical → const Set<GestureBound>