GestureConstraints class

Constructors

GestureConstraints({FrictionConfig? friction, DecayConfig? decay, double? perspective})
const

Properties

decay DecayConfig?
final
friction FrictionConfig?
final
hashCode int
The hash code for this object.
no setterinherited
perspective double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited