Settle class abstract

Rubber-back settle model. Produces a Flutter Simulation that starts at the decay's end position and velocity, and lands at the target. Origin renders the motion via the returned simulation, giving velocity continuity with the decay phase.

Implementers

Constructors

Settle()
const
Settle.attract({double stiffness})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simulationAt({required double position, required double velocity, required double target}) Simulation
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited