TapEvent class

Constructors

TapEvent({required Offset localPosition, required Offset globalPosition, required Future<void> animateToBase(), required Future<void> runEffect({Curve curve, Duration duration, double? perspective, double? rotateX, double? rotateY, double? rotateZ})})

Properties

animateToBase Future<void> Function()
final
globalPosition Offset
final
hashCode int
The hash code for this object.
no setterinherited
localPosition Offset
final
runEffect Future<void> Function({Curve curve, Duration duration, double? perspective, double? rotateX, double? rotateY, double? rotateZ})
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited