origin_blocker library

Classes

OriginBlocker
A widget stacked above origin items that must be hidden during the origin→display transition to avoid visual obstruction. A single blocker can block multiple origins, and multiple blockers can block the same origin.