OriginRect class

Constructors

OriginRect({required Rect rect, BorderRadius borderRadius = BorderRadius.zero, bool animate = true})
const

Properties

animate bool
final
borderRadius BorderRadius
final
hashCode int
The hash code for this object.
no setterinherited
rect Rect
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Rect? rect, BorderRadius? borderRadius, bool? animate}) OriginRect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited