OriginBounds class

Constructors

OriginBounds({required Set<OriginBound> bound, double value = 0, double? perspective, OriginBuilder? builder})
const
OriginBounds.directional({double value = 0, double? perspective, OriginBuilder? builder})
const
OriginBounds.horizontal({double value = 0, double? perspective, OriginBuilder? builder})
const
OriginBounds.scale({double value = 0, double? perspective, OriginBuilder? builder})
const
OriginBounds.vertical({double value = 0, double? perspective, OriginBuilder? builder})
const

Properties

bound Set<OriginBound>
final
builder OriginBuilder?
final
hashCode int
The hash code for this object.
no setterinherited
perspective double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited