friction method
See frictionFromState. Returns the friction-scaled delta for the given axis state under these bounds.
Implementation
double friction(AxisState state, double delta) =>
frictionFromState(state: state, bounds: this, delta: delta);
See frictionFromState. Returns the friction-scaled delta for the given axis state under these bounds.
double friction(AxisState state, double delta) =>
frictionFromState(state: state, bounds: this, delta: delta);