SimulationCurve class

Curve that exactly tracks a Simulation's position over its duration. Maps normalized animation time t ∈ [0, 1] to normalized position progress ∈ [0, 1].

Inheritance

Constructors

SimulationCurve(Simulation simulation, double realDuration)

Properties

flipped Curve
Returns a new curve that is the reversed inversion of this one.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
realDuration double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simulation Simulation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(double t) double
Returns the value of the curve at point t.
inherited
transformInternal(double t) double
Returns the value of the curve at point t.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited