transformInternal method
Returns the value of the curve at point t.
The given parametric value t will be between 0.0 and 1.0, inclusive.
Implementation
@override
double transformInternal(double t) {
if (_span == 0) return t;
return ((simulation.x(t * realDuration) - _start) / _span).clamp(0.0, 1.0);
}