onEnd property
The pointers are no longer in contact with the screen.
Implementation
@override
GestureScaleEndCallback? get onEnd => _onEnd == null ? null : (_) {};
The pointers are no longer in contact with the screen.
Implementation
@override
set onEnd(GestureScaleEndCallback? callback) => _onEnd = callback;