onUpdate property
The pointers in contact with the screen have indicated a new focal point and/or scale.
Implementation
GestureScaleUpdateCallback? onUpdate;
The pointers in contact with the screen have indicated a new focal point and/or scale.
Implementation
@override
set onUpdate(GestureScaleUpdateCallback? callback) {
_onUpdate = callback;
super.onUpdate = callback == null ? null : _trackingUpdate;
}