OriginEntry class
Constructors
Properties
- capture ↔ Widget Function()?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- measure ↔ OriginRect Function()?
-
getter/setter pair
-
open
↔ Future<
void> Function()? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
send
↔ Future<
void> Function(Rect (Rect), {VoidCallback? onEnd})? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited