Rotation class

Constructors

Rotation({double x = 0, double y = 0, double z = 0, double? perspective})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
perspective double?
0-1, maps to 0.001-0.005 perspective depth
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final
z double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMatrix4([double? fallbackPerspective]) Matrix4
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited