drag property
Stage-level fallback drag gestures. Origins under this Stage cascade through their own Origin.drag first, then this map for any unhandled keys.
Implementation
final Map<DragStart, DragGesture>? drag;
Stage-level fallback drag gestures. Origins under this Stage cascade through their own Origin.drag first, then this map for any unhandled keys.
final Map<DragStart, DragGesture>? drag;