isHybridDriving property
Live reader: true while Stage's hybrid merger is driving the rect. Origin reads this to silence its own rect manipulation while Stage is in control.
Implementation
final bool Function() isHybridDriving;
Live reader: true while Stage's hybrid merger is driving the rect. Origin reads this to silence its own rect manipulation while Stage is in control.
final bool Function() isHybridDriving;