Friction class
Resistance to motion during an active gesture, as a function of progress
through a bound state. Range 0, 1: 0 = no resistance, 1 = block.
Properties
Methods
-
evaluate(
double progress) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited