Gesture class

Constructors

Gesture({required Set<GestureStart> start, List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.horizontal({List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.one({List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.pinchIn({List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.pinchOut({List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.scale({List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.two({List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.twoHorizontal({List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.twoVertical({List<GestureBounds> bounds = const [], StageBuilder? builder})
const
Gesture.vertical({List<GestureBounds> bounds = const [], StageBuilder? builder})
const

Properties

bounds List<GestureBounds>
final
builder StageBuilder?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Set<GestureStart>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited