GestureBounds class

Constructors

GestureBounds({required Set<GestureBound> bound, double value = 0, double? perspective, StageBuilder? builder})
const
GestureBounds.directional({double value = 0, double? perspective, StageBuilder? builder})
const
GestureBounds.horizontal({double value = 0, double? perspective, StageBuilder? builder})
const
GestureBounds.scale({double value = 0, double? perspective, StageBuilder? builder})
const
GestureBounds.vertical({double value = 0, double? perspective, StageBuilder? builder})
const

Properties

bound Set<GestureBound>
final
builder StageBuilder?
final
hashCode int
The hash code for this object.
no setterinherited
perspective double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited