GestureStart enum
Values
- left → const GestureStart
- right → const GestureStart
- up → const GestureStart
- down → const GestureStart
- twoLeft → const GestureStart
- twoRight → const GestureStart
- twoUp → const GestureStart
- twoDown → const GestureStart
- pinchIn → const GestureStart
- pinchOut → const GestureStart
Properties
- bound → GestureBound
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isHorizontal → bool
-
no setter
- isOne → bool
-
no setter
- isScale → bool
-
no setter
- isTwo → bool
-
no setter
- isVertical → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
all
→ Set<
GestureStart> -
final
Constants
-
horizontal
→ const Set<
GestureStart> -
one
→ const Set<
GestureStart> -
scale
→ const Set<
GestureStart> -
two
→ const Set<
GestureStart> -
twoHorizontal
→ const Set<
GestureStart> -
twoVertical
→ const Set<
GestureStart> -
values
→ const List<
GestureStart> - A constant List of the values in this enum, in order of their declaration.
-
vertical
→ const Set<
GestureStart>