TapEvent class
Constructors
Properties
-
animateToBase
→ Future<
void> Function([Object? mode]) -
Opens the Origin onto the Stage. Optional
modeis a key into the Origin's Origin.modes map — when set, that mode's DisplayConfig is merged onto the default before animating. Use this to open with tool-specific configuration (e.g.event.animateToBase('crop_square')).final - globalPosition → Offset
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localPosition → Offset
-
final
-
runEffect
→ Future<
void> Function({Curve curve, Duration duration, double? perspective, double? rotateX, double? rotateY, double? rotateZ}) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited