OriginData class
- Inheritance
Constructors
-
OriginData({Key? key, required ValueNotifier<
OriginRect> origin, required ValueNotifier<OriginRect> originContainer, required ValueNotifier<OriginRect> display, required ValueNotifier<OriginRect> displayContainer, required ValueNotifier<double> aspectRatio, required ValueNotifier<Rect> rect, required ValueNotifier<Matrix4?> effectTransform, required ValueNotifier<Widget?> widget, required double? perspective, required OriginBuilder? gestureBuilder, required VoidCallback? onEnd, required Object? tag, required bool itemGesturing, required ValueSetter<double?> setPerspective, required ValueSetter<OriginBuilder?> setGestureBuilder, required ValueSetter<VoidCallback?> setOnEnd, required ValueSetter<Object?> setTag, required ValueSetter<bool> setItemGesturing, required ValueSetter<Rect> setRect, required AnimateRect animateRect, required VoidCallback reset, required Future<void> animateToBase(), required Future<void> dismiss(), required Future<void> runEffect({Curve curve, Duration duration, double? perspective, double? rotateX, double? rotateY, double? rotateZ}), required Widget child}) -
const
Properties
- animateRect → AnimateRect
-
final
-
animateToBase
→ Future<
void> Function() -
final
-
aspectRatio
→ ValueNotifier<
double> -
final
- borderRadius → BorderRadius
-
no setter
- child → Widget
-
The widget below this widget in the tree.
finalinherited
-
dismiss
→ Future<
void> Function() -
final
-
display
→ ValueNotifier<
OriginRect> -
final
-
displayContainer
→ ValueNotifier<
OriginRect> -
final
-
effectTransform
→ ValueNotifier<
Matrix4?> -
final
- gestureBuilder → OriginBuilder?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemGesturing → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onEnd → VoidCallback?
-
final
-
origin
→ ValueNotifier<
OriginRect> -
final
-
originContainer
→ ValueNotifier<
OriginRect> -
final
- perspective → double?
-
final
-
rect
→ ValueNotifier<
Rect> -
final
- reset → VoidCallback
-
final
-
runEffect
→ Future<
void> Function({Curve curve, Duration duration, double? perspective, double? rotateX, double? rotateY, double? rotateZ}) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setGestureBuilder
→ ValueSetter<
OriginBuilder?> -
final
-
setItemGesturing
→ ValueSetter<
bool> -
final
-
setOnEnd
→ ValueSetter<
VoidCallback?> -
final
-
setPerspective
→ ValueSetter<
double?> -
final
-
setRect
→ ValueSetter<
Rect> -
final
-
setTag
→ ValueSetter<
Object?> -
final
- tag → Object?
-
final
-
widget
→ ValueNotifier<
Widget?> -
final
Methods
-
createElement(
) → InheritedModelElement< String> -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
isSupportedAspect(
Object aspect) → bool -
Returns true if this model supports the given
aspect.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant OriginData oldWidget) → bool -
Whether the framework should notify widgets that inherit from this widget.
override
-
updateShouldNotifyDependent(
covariant OriginData oldWidget, Set< String> dependencies) → bool -
Return true if the changes between this model and
oldWidgetmatch any of thedependencies.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited