OriginItem class
The thumbnail source widget. Reports its rect + borderRadius as the origin.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- OriginItem
Constructors
-
OriginItem({Key? key, required Object tag, OriginTap? onTap, BorderRadius borderRadius = BorderRadius.zero, Object? containerTag, OriginRect? originContainer, OriginRect? display, OriginRect? displayContainer, List<
OriginGesture> gestures = const [], OriginConstraints constraints = const OriginConstraints(), double? aspectRatio, double? perspective, ValueSetter<OriginData> ? onEnd, Widget builder(BuildContext, Widget)?, required Widget child}) -
const
Properties
- aspectRatio → double?
-
final
- borderRadius → BorderRadius
-
final
- builder → Widget Function(BuildContext, Widget)?
-
final
- child → Widget
-
final
- constraints → OriginConstraints
-
final
- containerTag → Object?
-
final
- display → OriginRect?
-
final
- displayContainer → OriginRect?
-
final
-
gestures
→ List<
OriginGesture> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onEnd
→ ValueSetter<
OriginData> ? -
final
- onTap → OriginTap?
-
final
- originContainer → OriginRect?
-
final
- perspective → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → Object
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< OriginItem> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited