OriginScope class
Methods
-
createElement()
→ InheritedElement
-
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
measureContainer(Object tag)
→ OriginRect?
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
registerContainer(Object tag, OriginRect measure())
→ void
-
-
registerItem(Object tag, Future<void> trigger([Rect (Rect)?]))
→ void
-
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited
-
triggerItem(Object tag, [Rect send(Rect)?])
→ Future<void>
-
-
unregisterContainer(Object tag)
→ void
-
-
unregisterItem(Object tag)
→ void
-
-
updateShouldNotify(covariant OriginScope oldWidget)
→ bool
-
Whether the framework should notify widgets that inherit from this widget.
override