OriginStart enum
Values
- left → const OriginStart
- right → const OriginStart
- up → const OriginStart
- down → const OriginStart
- twoLeft → const OriginStart
- twoRight → const OriginStart
- twoUp → const OriginStart
- twoDown → const OriginStart
- pinchIn → const OriginStart
- pinchOut → const OriginStart
Properties
- bound → OriginBound
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isHorizontal → bool
-
no setter
- isOne → bool
-
no setter
- isScale → bool
-
no setter
- isTwo → bool
-
no setter
- isVertical → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
all
→ Set<
OriginStart> -
final
Constants
-
horizontal
→ const Set<
OriginStart> -
one
→ const Set<
OriginStart> -
scale
→ const Set<
OriginStart> -
two
→ const Set<
OriginStart> -
twoHorizontal
→ const Set<
OriginStart> -
twoVertical
→ const Set<
OriginStart> -
values
→ const List<
OriginStart> - A constant List of the values in this enum, in order of their declaration.
-
vertical
→ const Set<
OriginStart>