ReleaseContext class
Inputs the package used (and the consumer can use) to build a Release.
Pure data — gesture carries the bound configs (decay, friction)
and the maxScale/minScale used by the default plan.
Constructors
Properties
- aspectRatio → double
-
final
- baseRect → Rect
-
no setter
- currentRect → Rect
-
final
- displayRect → Rect
-
final
- gesture → Gesture
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleVelocity → double
-
final
- velocity → Velocity
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited