animateCrop property
Animates crop from its current value to the given rect. Used for
reset transitions and other places that want a smooth crop-rect change
instead of an instant stage.crop.value = newRect assignment.
Implementation
final AnimateRect animateCrop;